import { AbstractRepository } from '@crosslab/service-common';
import { InstantiableCloudDeviceModel } from '../../model.js';
export class InstantiableCloudDeviceRepository extends AbstractRepository {
    dependencies = {};
    constructor() {
        super('Instantiable Cloud Device');
    }
    dependenciesMet() {
        if (!this.dependencies.deviceOverview)
            return false;
        return true;
    }
    initialize(entityManager) {
        this.repository = entityManager.getRepository(InstantiableCloudDeviceModel);
    }
    async create(data) {
        const model = await super.create(data);
        model.type = 'cloud instantiable';
        return model;
    }
    async write(model, data) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        await this.dependencies.deviceOverview.write(model, data);
        if (data.instantiateUrl)
            model.instantiateUrl = data.instantiateUrl;
        if (data.services)
            model.services = data.services;
    }
    async format(model) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        return {
            ...(await this.dependencies.deviceOverview.format(model)),
            type: 'cloud instantiable',
            instantiateUrl: model.instantiateUrl,
            services: model.services ?? undefined,
        };
    }
}
//# sourceMappingURL=instantiableCloudDevice.js.map